# SChem

Clean Room implementation of the backend of SpaceChem (https://www.zachtronics.com/spacechem).

## Usage

`python game.py [solution_file]`

Will validate the cycles-reactors-symbols score of the provided solution file, or of any solution in the user's
clipboard if a file is not specified.
